const isExpired = (entry, expire = 0) => !!expire && entry.timestamp + expire < Date.now();
const isSameVersion = (entry, version) => entry.version === version;
const setItem = (key, data, { version, storage }) => {
    const entry = {
        timestamp: Date.now(),
        data,
        version,
    };
    storage.setItem(key, JSON.stringify(entry));
    return entry;
};
const getItem = (key, options) => {
    const { storage, version, expire } = options;
    const entry = JSON.parse(storage.getItem(key));
    if (!entry || isExpired(entry, expire) || !isSameVersion(entry, version)) {
        removeItem(key, options);
        return null;
    }
    return entry;
};
const removeItem = (key, { storage }) => {
    storage.removeItem(key);
};
export function getBucket(name, options) {
    options = Object.assign({ storage: localStorage }, options);
    return [
        () => {
            const entry = getItem(name, options);
            return entry ? entry.data : options.defaultValue;
        },
        (value) => {
            setItem(name, value, options);
        },
        () => {
            removeItem(name, options);
        },
    ];
}
